@@ -17,8 +17,7 @@
 
 from gettext import gettext as _
 
-# MAYBE/2019-12-05: (lb): Decouple dob-viewer from click, used only for term. size.
-import click_hotoffthehamster as click  # merely for get_terminal_size.
+import click_hotoffthehamster as click
 
 from nark.helpers.format_text import format_value_truncate
 from nark.helpers.objects import resolve_attr_or_method
