@@ -22,15 +22,14 @@ from gettext import gettext as _
 import asyncio
 import time
 
-# (lb): We're using Click only for get_terminal_size. (The
-#  UI and user interaction is otherwise all handled by PPT).
-# MAYBE/2019-12-05: (lb): Decouple dob-viewer from click, used only for term. size.
-import click_hotoffthehamster as click  # merely for get_terminal_size.
+import click_hotoffthehamster as click
 
 from inflector import English, Inflector
 
 from nark.helpers.dev.profiling import profile_elapsed
 
+from dob_bright.termio.errors import dob_been_warned_reset
+
 from dob_viewer.ptkui.re_confirm import confirm
 
 from ..config.styling.style_conf import color as styling_color
@@ -157,15 +156,15 @@ class Carousel(object):
             self.style_classes = style_classes
 
         def setup_rules_confobj(rules_confobj):
-            self.stylability = StyleEngine(rules_confobj)
+            self.style_engine = StyleEngine(rules_confobj)
 
         _setup_styling()
 
-    def add_stylable_classes(self, ppt_widget, friendly_name, fact=None):
+    def process_style_rules(self, ppt_widget, friendly_name, fact=None):
         """Apply custom user classes from ~/.config/dob/styling/styles|rules.conf
         to, e.g., use custom color backgrounds for Facts with matching Category."""
         fact = fact or self.carousel.edits_manager.curr_edit
-        return self.stylability.add_stylable_classes(ppt_widget, friendly_name, fact)
+        return self.style_engine.process_style_rules(ppt_widget, friendly_name, fact)
 
     # ***
 
@@ -334,12 +333,46 @@ class Carousel(object):
         self.edits_manager.stand_up()
 
     def standup_always(self, **kwargs):
+        self.managers_standup()
+        return self.check_nak_if_errors_or_build_and_show(**kwargs)
+
+    def managers_standup(self):
         self.zone_manager = ZoneManager(self)
         self.zone_manager.standup()
         self.action_manager.standup()
         self.update_handler.standup()
-        self.action_manager.finalize_standup()  # Prints key binding errors.
-        self.zone_manager.build_and_show(**kwargs)
+        self.action_manager.finalize_standup()
+
+    def check_nak_if_errors_or_build_and_show(self, **kwargs):
+        # Linger for errors, with basic config, style config, key binding,
+        # etc., otherwise Carousel overwrites screen and user won't see them.
+        if self.pause_on_error_message_maybe():
+            self.zone_manager.build_and_show(**kwargs)
+            return True
+        return False
+
+    def pause_on_error_message_maybe(self):
+        if not dob_been_warned_reset():
+            return True
+        # (lb): My first approach was to sleep:
+        #   time.sleep(2.666)
+        # but perhaps requiring acknowledgement is better, because even after
+        # quitting editor, error is still not visible unless the user scrolls.
+        # - There's a Linux-only single-key reader, i.e., so user needs not ENTER,
+        #     https://pypi.org/project/readchar/
+        #   or, for cross-platform solution, see:
+        #     https://stackoverflow.com/questions/510357/
+        #       python-read-a-single-character-from-the-user
+        #   but that seems like a lot of extra work for error handler.
+        click.echo(_('Press ENTER to acknowledge.'))
+        # Be sure to gobble more than user types, lest it goes to PTK input.
+        stdin_text = click.get_text_stream('stdin')
+        try:
+            stdin_text.readline()
+        except KeyboardInterrupt:
+            click.echo(_('You got it!'))
+            return False
+        return True
 
     # ***
 
@@ -365,7 +398,8 @@ class Carousel(object):
         # I mean I added this code last, and it might all that's needed to get
         # around the CPR issue (in which case, the `enduring_edit is None`
         # kludge below may be unnecessary).
-        self.standup_always(**kwargs)
+        if not self.standup_always(**kwargs):
+            return False
 
         if self.async_enable:
             rerun = self.runloop_async()
