@@ -179,7 +179,7 @@ class UpdateHandler(object):
 
     @catch_action_exception
     @ZoneContent.Decorators.reset_showing_help
-    def fact_paste(self, event):
+    def fact_paste(self, event=None):
         """"""
         def _fact_paste():
             paste_what = self.edits_manager.paste_copied_meta()
@@ -698,7 +698,12 @@ class UpdateHandler(object):
         try:
             delta_time = int(self.command_modifier)
         except ValueError:
-            delta_time = float(self.command_modifier)
+            try:
+                delta_time = float(self.command_modifier)
+            except ValueError:
+                # Happens if user entered, e.g., a date string but then
+                # pressed a [count] modifier command. E.g., '2020-04-01'.
+                return None
         return delta_time
 
     def apply_count_multiplier(self, count=1, floats=False):
@@ -730,3 +735,76 @@ class UpdateHandler(object):
             self.delta_time_keycode = ''
         self.zone_manager.zone_lowdown.reset_status()
 
+    # ***
+
+    def complete_active_and_start_now(self):
+        edit_fact = self.edits_manager.editable_fact()
+        if not edit_fact.is_gap:
+            start_or_end = 'end'
+        else:
+            # Activate Fact is gap Fact, and we want to start new Fact now,
+            # knowingly leaving a gap behind, so bump gap's start.
+            start_or_end = 'start'
+        delta_mins_or_time = timedelta()  # I.e., 0.
+        self.edits_manager.edit_time_adjust(
+            delta_mins_or_time=delta_mins_or_time,
+            start_or_end=start_or_end,
+            end_maybe=None,
+            gap_okay=True,
+            modified=False,
+        )
+
+    # ***
+
+    @catch_action_exception
+    def copy_complete_and_paste_active(self, event):
+        self.fact_copy_fact(event)
+        self.edits_manager.jump_fact_final()
+        self.fact_paste(event)
+
+    # ***
+
+    @catch_action_exception
+    def copy_complete_and_paste_new(self, event):
+        self.edits_manager.fact_copy_fact()
+        self.edits_manager.jump_fact_final()
+        self.complete_active_and_start_now()
+        self.edits_manager.jump_fact_inc()
+        self.fact_paste()
+
+    # ***
+
+    @catch_action_exception
+    def complete_and_prompt_new(self, event):
+        self.edits_manager.jump_fact_final()
+        self.complete_active_and_start_now()
+        self.edits_manager.jump_fact_inc()
+        self.edit_actegory(event)
+
+    # ***
+
+    @catch_action_exception
+    def custom_factoid_paste(self, event):
+        keycode = self._key_sequence_str(event)
+        # (lb): Highly coupled now. I know. Oh well.
+        keyed_factoids = self.carousel.action_manager.key_bonder.keyed_factoids
+        try:
+            user_factoid = keyed_factoids[keycode]
+        except AttributeError:
+            self.carousel.controller.affirm(False)  # Should not get this far.
+            pass
+        else:
+            pasted, errmsg = self.edits_manager.paste_factoid(user_factoid)
+            if errmsg is not None:
+                self.zone_manager.show_message_and_deny_leave(
+                    self.zone_manager.root,
+                    _('Factoid?'),
+                    errmsg,
+                )
+            elif not pasted:
+                hot_notif = _("Already pasted factoid")
+            else:
+                self.zone_manager.rebuild_viewable()
+                hot_notif = _("Pasted custom factoid")
+            self.zone_manager.update_status(hot_notif)
+
